@@ -33,16 +33,16 @@ class BOTAN_DLL Noekeon : public Block_Cipher_Fixed_Params<16, 16>
       /**
       * @return const reference to encryption subkeys
       */
-      const secure_vector<u32bit>& get_EK() const { return EK; }
+      const secure_vector<u32bit>& get_EK() const { return m_EK; }
 
       /**
       * @return const reference to decryption subkeys
       */
-      const secure_vector<u32bit>& get_DK() const { return DK; }
+      const secure_vector<u32bit>& get_DK() const { return m_DK; }
 
    private:
       void key_schedule(const byte[], size_t) override;
-      secure_vector<u32bit> EK, DK;
+      secure_vector<u32bit> m_EK, m_DK;
    };
 
 }
